@@ -13,7 +13,7 @@ def rd():
     print("xlrd {:0.1f}s".format(end - start))
     use = memory_usage(proc=-1, interval=1)[0]
     print("Memory use %.1f MB" % use)
-    print_summary()
+    #print_summary()
 
 
 def pixel():
@@ -23,11 +23,11 @@ def pixel():
     print("openpyxl {:0.1f} s".format(end - start))
     use = memory_usage(proc=-1, interval=1)[0]
     print("Memory use %.1f MB" % use)
-    print_summary()
+    #print_summary()
 
 
 if __name__ == '__main__':
     from openpyxl import __version__
     print(__version__)
-    #rd()
-    pixel()
+    rd()
+    #pixel()
